package de.ozgcloud.apilib.common.command.grpc;

import java.time.ZonedDateTime;
import java.util.Map;
import java.util.UUID;

import de.ozgcloud.apilib.common.command.OzgCloudCommand;
import de.ozgcloud.apilib.common.command.OzgCloudCommandId;
import de.ozgcloud.apilib.common.command.OzgCloudCommandStatus;
import de.ozgcloud.apilib.file.OzgCloudFileTestFactory;
import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;
import de.ozgcloud.common.datatype.StringBasedValue;

public class OzgCloudCommandTestFactory {

	public static final OzgCloudCommandId ID = OzgCloudCommandId.from(UUID.randomUUID().toString());

	public static final OzgCloudVorgangId VORGANG_ID = OzgCloudVorgangTestFactory.ID;
	public static final StringBasedValue RELATION_ID = OzgCloudFileTestFactory.ID;
	public static final long RELATION_VERSION = 42;

	public static final String ORDER = "CREATE_NOTE";
	public static final OzgCloudCommandStatus STATUS = OzgCloudCommandStatus.FINISHED;

	public static final String CREATED_AT_STR = "2023-08-18T13:54:10Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);
	public static final String FINISHED_AT_STR = "2023-08-18T13:55:10Z";
	public static final ZonedDateTime FINISHED_AT = ZonedDateTime.parse(FINISHED_AT_STR);

	public static final String BODY_FIELD_NAME = "FIELD";
	public static final String BODY_FIELD_VALUE = "42";
	public static final Map<String, Object> BODY = Map.of(BODY_FIELD_NAME, BODY_FIELD_VALUE);
	public static final String CREATED_RESOURCE = UUID.randomUUID().toString();
	public static final OzgCloudUserId CREATED_BY = OzgCloudUserId.from(UUID.randomUUID().toString());
	public static final String CREATED_BY_NAME = "Dorothea Dow";
	public static final String ERROR_MESSAGE = "An error occurred";

	public static OzgCloudCommand create() {
		return createBuilder().build();
	}

	public static OzgCloudCommand.OzgCloudCommandBuilder createBuilder() {
		return OzgCloudCommand.builder()
				.id(ID)
				.vorgangId(VORGANG_ID)
				.relationId(RELATION_ID)
				.relationVersion(RELATION_VERSION)
				.order(ORDER)
				.status(STATUS)
				.createdAt(CREATED_AT)
				.finishedAt(FINISHED_AT)
				.bodyObject(BODY)
				.createdResource(CREATED_RESOURCE)
				.createdBy(CREATED_BY)
				.errorMessage(ERROR_MESSAGE);
	}
}
