/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.client.autoconfigure;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import de.ozgcloud.apilib.autoconfig.ApiLibTestApplication;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangService;
import de.ozgcloud.apilib.vorgang.dummy.DummyVorgangService;
import de.ozgcloud.apilib.vorgang.grpc.GrpcOzgCloudVorgangService;

public class OzgCloudVorgangServiceStarterITCase {

	@Nested
	@SpringBootTest(classes = ApiLibTestApplication.class, properties = {
		"ozgcloud.vorgang-manager.address=address"
	})
	class TestWithOzgCloudVorgangService {

		@Autowired
		private OzgCloudVorgangService ozgCloudVorgangService;

		@Test
		void shouldStart() {
			assertThat(ozgCloudVorgangService).isInstanceOf(GrpcOzgCloudVorgangService.class);
		}
	}

	@Nested
	@SpringBootTest(classes = ApiLibTestApplication.class)
	class TestWithExistingOzgCloudVorgangService {

		@Autowired
		private OzgCloudVorgangService ozgCloudVorgangService;

		@Test
		void shouldStart() { // NOSONAR
			assertThat(ozgCloudVorgangService).isInstanceOf(DummyVorgangService.class);
		}

	}
}
